#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from ovsdbapp.schema.ovn_southbound import impl_idl
from ovsdbapp.tests.functional.schema import fixtures


class SbApiFixture(fixtures.ApiImplFixture):
    api_cls = impl_idl.OvnSbApiIdlImpl


class ChassisFixture(fixtures.ImplIdlFixture):
    create = 'chassis_add'
    delete = 'chassis_del'
